@@ -26,4 +26,7 @@ if __name__ == '__main__':
         alpha=args.alpha,
         auto_alpha=args.auto_alpha)
     trainer = Trainer(policy, env, args, test_env=test_env)
-    trainer()
+    if args.evaluate:
+        trainer.evaluate_policy_continuously()
+    else:
+        trainer()
